==> fuel-ui-0.4.1-3.tgz: package/esm/components/Tag/Tag.js <==
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { NgModule, Directive, Input, Output, EventEmitter } from '@angular/core';
import { CommonModule } from "@angular/common";
import { TagSet } from './TagSet';
export let Tag = class Tag {
    constructor(tagset) {
        this.removable = false;
        this.remove = new EventEmitter(false);
        this.classMap = {};
        this.tagset = tagset;
        this.tagset.addTag(this);
    }
    get pill() { return this._pill; }
    ;
    set pill(value) {
        this._pill = value;
        this.setClassMap();
    }
    get color() { return this._color; }
    ;
    set color(value) {
        this._color = value;
        this.setClassMap();
    }
    get disabled() { return this._disabled; }
    ;
    set disabled(value) {
        this._disabled = value;
        this.setClassMap();
    }
    ngOnInit() {
        this.color = this.color !== 'undefined' ? this.color : 'default';
    }
    ngOnDestroy() {
        this.remove.next(this);
        this.tagset.removeTag(this);
    }
    setClassMap() {
        this.classMap = {
            'disabled': this.disabled,
            'label-pill': this.pill,
            ['label-' + ((this.color && this.color.toLowerCase()) || 'default')]: true
        };
    }
};
__decorate([
    Input(), 
    __metadata('design:type', String)
], Tag.prototype, "title", void 0);
__decorate([
    Input(), 
    __metadata('design:type', Object)
], Tag.prototype, "value", void 0);
__decorate([
    Input(), 
    __metadata('design:type', Boolean)
], Tag.prototype, "removable", void 0);
__decorate([
    Input(), 
    __metadata('design:type', Boolean)
], Tag.prototype, "pill", null);
__decorate([
    Input(), 
    __metadata('design:type', String)
], Tag.prototype, "color", null);
__decorate([
    Input(), 
    __metadata('design:type', Boolean)
], Tag.prototype, "disabled", null);
__decorate([
    Output(), 
    __metadata('design:type', EventEmitter)
], Tag.prototype, "remove", void 0);
Tag = __decorate([
    Directive({
        selector: 'tag, [tag]'
    }), 
    __metadata('design:paramtypes', [TagSet])
], Tag);
const tagDirectives = [
    Tag,
    TagSet
];
export let FuiTagModule = class FuiTagModule {
};
FuiTagModule = __decorate([
    NgModule({
        imports: [CommonModule],
        declarations: tagDirectives,
        exports: tagDirectives
    }), 
    __metadata('design:paramtypes', [])
], FuiTagModule);

==> fuel-ui-0.4.1-5.tgz: package/esm/components/Tag/Tag.js <==
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { NgModule, Directive, Input, Output, EventEmitter } from '@angular/core';
import { CommonModule } from "@angular/common";
import { TagSet } from './TagSet';
export let Tag = class Tag {
    constructor(tagset) {
        this.removable = false;
        this.remove = new EventEmitter(false);
        this.classMap = {};
        this.tagset = tagset;
        this.tagset.addTag(this);
    }
    get pill() { return this._pill; }
    ;
    set pill(value) {
        this._pill = value;
        this.setClassMap();
    }
    get color() { return this._color; }
    ;
    set color(value) {
        this._color = value;
        this.setClassMap();
    }
    get disabled() { return this._disabled; }
    ;
    set disabled(value) {
        this._disabled = value;
        this.setClassMap();
    }
    ngOnInit() {
        this.color = this.color !== 'undefined' ? this.color : 'default';
    }
    ngOnDestroy() {
        this.remove.next(this);
        this.tagset.removeTag(this);
    }
    setClassMap() {
        this.classMap = {
            'disabled': this.disabled,
            'tag-pill': this.pill,
            ['tag-' + ((this.color && this.color.toLowerCase()) || 'default')]: true
        };
    }
};
__decorate([
    Input(), 
    __metadata('design:type', String)
], Tag.prototype, "title", void 0);
__decorate([
    Input(), 
    __metadata('design:type', Object)
], Tag.prototype, "value", void 0);
__decorate([
    Input(), 
    __metadata('design:type', Boolean)
], Tag.prototype, "removable", void 0);
__decorate([
    Input(), 
    __metadata('design:type', Boolean)
], Tag.prototype, "pill", null);
__decorate([
    Input(), 
    __metadata('design:type', String)
], Tag.prototype, "color", null);
__decorate([
    Input(), 
    __metadata('design:type', Boolean)
], Tag.prototype, "disabled", null);
__decorate([
    Output(), 
    __metadata('design:type', EventEmitter)
], Tag.prototype, "remove", void 0);
Tag = __decorate([
    Directive({
        selector: 'tag, [tag]'
    }), 
    __metadata('design:paramtypes', [TagSet])
], Tag);
const tagDirectives = [
    Tag,
    TagSet
];
export let FuiTagModule = class FuiTagModule {
};
FuiTagModule = __decorate([
    NgModule({
        imports: [CommonModule],
        declarations: tagDirectives,
        exports: tagDirectives
    }), 
    __metadata('design:paramtypes', [])
], FuiTagModule);
